<?php
/**
 * Sepordeh Payment Gateway for LifterLMS
 * @since    1.0.0
 * @version  1.0.0
 * @author   Sepordeh
 */

if ( ! defined( 'ABSPATH' ) ) { exit; }

class LLMS_Payment_Gateway_Sepordeh extends LLMS_Payment_Gateway {




    const REDIRECT_URL = "https://sepordeh.com/merchant/invoices/pay/automatic:true/id:";

    const MIN_AMOUNT = 1001;

    public $MerchantID = '';



    /**
     * Constructor
     * @since    1.0.0
     * @version  1.0.0
     */
    public function __construct() {

        $this->id = 'Sepordeh';
        $this->icon = '<a href="https://www.Sepordeh.com"  onclick="javascript:window.open(\'https://www.Sepordeh.com\',\'sepordeh\',\'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=yes, resizable=yes, width=1060, height=700\'); return false;"><img src="https://sepordeh.com/templates/main/images/logo.png" border="0" alt="sepordeh logo"></a>';
        $this->admin_description = __( 'Allow customers to purchase courses and memberships using Sepordeh.', 'lifterlms-Sepordeh' );
        $this->admin_title = 'Sepordeh';
        $this->title = 'Sepordeh';
        $this->description = __( 'Pay via Sepordeh', 'lifterlms-Sepordeh' );

        $this->supports = array(
            'single_payments' => true,
        );


        // add Sepordeh specific fields
        add_filter( 'llms_get_gateway_settings_fields', array( $this, 'settings_fields' ), 10, 2 );

        // output Sepordeh account details on confirm screen
        add_action( 'lifterlms_checkout_confirm_after_payment_method', array( $this, 'after_payment_method_details' ) );
    }


    public function after_payment_method_details() {

        $key = isset( $_GET['order'] ) ? $_GET['order'] : '';

        $order = llms_get_order_by_key( $key );
        if ( ! $order || 'Sepordeh' !== $order->get( 'payment_gateway' ) ) {
            return;
        }

        echo '<input name="llms_sepordeh.com_token" type="hidden" value="' . $_GET['authority'] . '">';

    }

    /**
     * Output some information we need on the confirmation screen
     * @return   void
     * @since    1.0.0
     * @version  1.0.0
     */
    public function confirm_pending_order( $order ) {



        if ( ! $order || 'Sepordeh' !== $order->get( 'payment_gateway' ) ) {
            return;
        }

        $this->log( 'Sepordeh `after_payment_method_callback()` started', $order, $_POST );



        $Authority = $_GET['authority'];
        $data = array('MerchantID' => self::get_MerchantID(), 'Authority' => $Authority, 'Amount' => $order->get_price( 'total', array(), 'float' ));
      
$url='https://sepordeh.com/merchant/invoices/verify';
$params= [
		'merchant' 	=> self::get_MerchantID(),
		'authority' => $Authority,
	];
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$res = curl_exec($ch);
	curl_close($ch);
$result = json_decode($res);


        if ($result->status ==200) {
            $txn_data = array();
            $txn_data['amount'] = $order->get_price( 'total', array(), 'float' );
            $txn_data['transaction_id'] = $result->information->invoice_id;
            $txn_data['status'] = 'llms-txn-succeeded';
            $txn_data['payment_type'] = 'single';
            $txn_data['source_description'] = isset( $_POST['card_holder'] ) ? $_POST['card_holder'] : '';

            $order->record_transaction( $txn_data );

            $this->log( $order, 'Sepordeh `confirm_pending_order()` finished' );


            $order->add_note('شماره تراکنش : ' .$result->information->invoice_id );

            $this->complete_transaction( $order );

        }else{
            $this->log( $order, 'Sepordeh `confirm_pending_order()` finished with error : ' .$result->status  );
            $order->add_note('Faild Transaction : ' .$result->status  );

            wp_safe_redirect( llms_cancel_payment_url() );
            exit();

        }

    }

    /**
     * Get $MerchantID option
     * @return   string
     * @since    1.0.0
     * @version  1.0.0
     */
    public function get_MerchantID() {
        return $this->get_option( 'MerchantID' );
    }


    /**
     * Handle a Pending Order
     * Called by LLMS_Controller_Orders->create_pending_order() on checkout form submission
     * All data will be validated before it's passed to this function
     *
     * @param   obj       $order   Instance LLMS_Order for the order being processed
     * @param   obj       $plan    Instance LLMS_Access_Plan for the order being processed
     * @param   obj       $person  Instance of LLMS_Student for the purchasing customer
     * @param   obj|false $coupon  Instance of LLMS_Coupon applied to the order being processed, or false when none is being used
     * @return  void
     * @since   1.0.0
     * @version 1.0.0
     */
    public function handle_pending_order( $order, $plan, $person, $coupon = false ) {

        $this->log( 'Sepordeh `handle_pending_order()` started', $order, $plan, $person, $coupon );

        // do some gateway specific validation before proceeding
        $total = $order->get_price( 'total', array(), 'float' );
        if ( $total < self::MIN_AMOUNT ) {
            return llms_add_notice( sprintf( __( 'با توجه به محدوديت هاي شاپرك امكان پرداخت با رقم درخواست شده ميسر نمي باشد حداقل مبلغ پرداختی  %s تومان است', 'lifterlms-Sepordeh' ), self::MIN_AMOUNT ), 'error' );
        }

        $data = array('MerchantID' => self::get_MerchantID(),
            'Amount' => $order->get_price( 'total', array(), 'float' ),
            'CallbackURL' => llms_confirm_payment_url( $order->get( 'order_key' )),
            'Description' => $order->get( 'order_key' ));
   
$url='https://sepordeh.com/merchant/invoices/add';
		$params=array(
		'merchant'          =>  self::get_MerchantID(),
		'amount'       => $order->get_price( 'total', array(), 'float' ),
		'callback'     => llms_confirm_payment_url( $order->get( 'order_key' )),
		'orderId' =>  $order->get( 'order_key' ),
		'description'  => $order->get( 'order_key' ),
	);
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$res = curl_exec($ch);
	curl_close($ch);

	$result = json_decode($res);
        if($result->status==200)
        {
            $this->log( $r, 'Sepordeh `handle_pending_order()` finished' );
            do_action( 'lifterlms_handle_pending_order_complete', $order );
            $order->add_note('transaction ID : ' . $result->information->invoice_id );
            wp_redirect( self::REDIRECT_URL . $result->information->invoice_id );
            exit();
        }
        else
        {
            $this->log( $r, 'Sepordeh `handle_pending_order()` finished with error code : ' );
            return llms_add_notice( 'خطا در اتصال به درگاه : ' . $result["Status"] , 'error' );
        }

    }




    /**
     * Output custom settings fields on the LifterLMS Gateways Screen
     * @param    array     $fields      array of existing fields
     * @param    string    $gateway_id  id of the gateway
     * @return   array
     * @since    1.0.0
     * @version  1.0.0
     */
    public function settings_fields( $fields, $gateway_id ) {

        // don't add fields to other gateways!
        if ( $this->id !== $gateway_id ) {
            return $fields;
        }

        $fields[] = array(
            'type'  => 'custom-html',
            'value' => '
				<h4>' . __( 'Sepordeh Settings', 'lifterlms-Sepordeh' ) . '</h4>
				<p>' . __( 'مرچنت کد  خود را برای اتصال به سپرده وارد کنید ', 'lifterlms-Sepordeh' ) . '</p>
			',
        );

        $settings = array(
            'MerchantID' => __( 'مرچنت کد', 'lifterlms-Sepordeh' ),
        );
        foreach( $settings as $k => $v ) {
            $fields[] = array(
                'id'            => $this->get_option_name( $k ),
                'default'       => $this->{'get_' . $k}(),
                'title'         => $v,
                'type'          => 'text',
            );
        }


        return $fields;

    }

}
